@@ -13,7 +13,7 @@ namespace rmmseg
     {
         unsigned char   nbytes;   /* number of bytes */
         char            length;   /* number of characters */
-        unsigned        freq;
+        unsigned short  freq;
         char            text[word_embed_len];
     };
 
@@ -23,16 +23,16 @@ namespace rmmseg
      * freq: the frequency of the word.
      */
     inline Word *make_word(const char *text, int length=1,
-                           unsigned freq=0, int nbytes=-1)
+                           int freq=0, int nbytes=-1)
     {
-        if (freq > UINT_MAX)
-            freq = UINT_MAX;   /* avoid overflow */
+        if (freq > USHRT_MAX)
+            freq = USHRT_MAX;   /* avoid overflow */
         if (nbytes == -1)
-            nbytes = strlen(text);
+            nbytes = std::strlen(text);
         Word *w = static_cast<Word *>(pool_alloc(sizeof(Word)
                                                  + nbytes+1
                                                  - word_embed_len));
-        w->nbytes = std::strlen(text);
+        w->nbytes = nbytes;
         w->length = length;
         w->freq = freq;
         std::strncpy(w->text, text, nbytes);
